Add a column to the dataRetrieval data frame with the water year. WQP
queries will return a water year column for the start and end dates
of the data.
Arguments
- rawData
the daily- or unit-values datset retrieved from NWISweb. Must
have at least one of the following columns to add the new water year columns:
dateTime, Date, ActivityStartDate, or ActivityEndDate. The date column(s)
can be character, POSIXct, Date. They cannot be numeric.
Value
data.frame with an additional integer column with "WY" appended to the
date column name. For WQP, there will be 2 columns: ActivityStartDateWY and
ActivityEndDateWY.
Examples
# \donttest{
# nwisData <- readNWISdv("04085427", "00060", "2022-01-01", "2022-06-30")
# nwisData <- addWaterYear(nwisData)
# wqpData <- readWQPqw("USGS-01594440", "01075", "", "")
# wqpData <- addWaterYear(wqpData)
# }