check_arguments_api: Check other arguments

View source: R/get_ogc_data.R

check_arguments_apiR Documentation

Check other arguments

Description

Additional functions to check types and create parameter descriptions.

Usage

check_arguments_api(bbox, skipGeometry)

Arguments

bbox

Only features that have a geometry that intersects the bounding box are selected.The bounding box is provided as four or six numbers, depending on whether the coordinate reference system includes a vertical axis (height or depth). Coordinates are assumed to be in crs 4326. The expected format is a numeric vector structured: c(xmin,ymin,xmax,ymax). Another way to think of it is c(Western-most longitude, Southern-most latitude, Eastern-most longitude, Northern-most longitude).

skipGeometry

This parameter can be used to skip response geometries for each feature. The returning object will be a data frame with no spatial information. The default NA will not specify the argument in the request.


dataRetrieval documentation built on May 28, 2026, 9:06 a.m.