check_arguments_non_api: Check non-API arguments

View source: R/get_ogc_data.R

check_arguments_non_apiR Documentation

Check non-API arguments

Description

Function to check types and create parameter descriptions.

Usage

check_arguments_non_api(
  convertType,
  no_paging,
  limit,
  attach_request,
  chunk_size,
  ...
)

Arguments

convertType

logical, defaults to TRUE. If TRUE, the function will convert the data to dates, any qualifiers to string vector and reorder the returned data frame.

no_paging

logical, defaults to FALSE. If TRUE, the data will be requested from a native csv format. This can be dangerous because the data will cut off at 50,000 rows without indication that more data is available. Use TRUE with caution.

limit

numeric, The optional limit parameter is used to control the subset of the selected features that should be returned in each page. The maximum allowable limit is 50,000. It may be beneficial to set this number lower if your internet connection is spotty. The default (NA) will set the limit to the maximum allowable limit for the service.

attach_request

logical, defaults to TRUE. If set to TRUE, the full request sent to the Water Data API is attached as an attribute to the data set.

chunk_size

Number of monitoring_location_ids to chunk requests into. The default for functions that don't generally return long-term data records is 250, while the default for time series functions is 10. Setting to NA will eliminate site chunking, giving users full control.

...

Not used. Included to help differentiate official Water Data API arguments from more seldom used, optional dataRetrieval-specific arguments.


dataRetrieval documentation built on May 28, 2026, 9:06 a.m.