dataRetrieval: Retrieval functions for USGS and EPA data

dataRetrievalR Documentation

Retrieval functions for USGS and EPA data

Description

Package: dataRetrieval
Type: Package
License: Unlimited for this package, dependencies have more restrictive licensing.
Copyright: This software is in the public domain because it contains materials that originally came from the United States Geological Survey, an agency of the United States Department of Interior.
LazyLoad: yes

Details

Retrieval functions for USGS and EPA hydrologic and water quality data.

Please see https://doi-usgs.github.io/dataRetrieval/ for more information.

Author(s)

Laura De Cicco ldecicco@usgs.gov

See Also

Useful links:


dataRetrieval documentation built on March 31, 2026, 5:07 p.m.