Learn R Programming

dataRetrieval (version 1.4.0)

formatCheckDate: formatCheckDate

Description

Response to the date format checker. If the date is not formated correctly, it will give the user the opportunity to correct, otherwise will create a warning.

Usage

formatCheckDate(Date, dateString, interactive = TRUE)

Arguments

Date

string

dateString

string used in either error message or interactive message. An example would be "startDate"

interactive

logical Option for interactive mode. If true, there is user interaction for error handling and data checks.

Value

condition logical if TRUE,

Examples

Run this code
# NOT RUN {
Date <- '1985-01-01'
dateString <- 'startDate'
formatCheckDate(Date, dateString, interactive = FALSE)
# }

Run the code above in your browser using DataLab