Learn R Programming

dataRetrieval (version 1.4.0)

formatCheckParameterCd: formatCheckParameterCd

Description

Checks that the parameter code is 5 digits. If it is less, it will pad the string with zeros. If more, ask the user to re-enter.

Usage

formatCheckParameterCd(parameterCd, interactive = TRUE)

Arguments

parameterCd

string to check

interactive

logical Option for interactive mode. If true, there is user interaction for error handling and data checks.

Value

parameterCd string

Examples

Run this code
# NOT RUN {
pCode <- '01234'
formatCheckParameterCd(pCode)
# }

Run the code above in your browser using DataLab