Learn R Programming

dataRetrieval (version 1.4.0)

getDailyDataFromFile: Import Daily Data for WRTDS

Description

This function is being deprecated for getUserDaily.

Usage

getDailyDataFromFile(filePath, fileName, hasHeader = TRUE, separator = ",",
  qUnit = 1, interactive = TRUE)

Arguments

filePath

string specifying the path to the file

fileName

string name of file to open

hasHeader

logical true if the first row of data is the column headers

separator

string character that separates data cells

qUnit

number 1 is cubic feet per second, 2 is cubic meters per second, 3 is 10^3 cubic feet per second, and 4 is 10^3 cubic meters per second

interactive

logical Option for interactive mode. If true, there is user interaction for error handling and data checks.

Value

Daily dataframe

Examples

Run this code
# NOT RUN {
filePath <- system.file("extdata", package="dataRetrieval")
filePath <- paste(filePath,"/",sep="")
fileName <- "ChoptankRiverFlow.txt"
# }
# NOT RUN {
Daily <- getDailyDataFromFile(filePath,fileName,separator="\t")
# }

Run the code above in your browser using DataLab