Learn R Programming

dataRetrieval (version 1.4.0)

getNWISInfo: Import Metadata for USGS Data

Description

Populates INFO data frame for EGRET study. If either station number or parameter code supplied, imports data about a particular USGS site from NWIS web service. This function gets the data from here: http://waterservices.usgs.gov/ A list of parameter codes can be found here: http://nwis.waterdata.usgs.gov/nwis/pmcodes/ If either station number or parameter code is not supplied, the user will be asked to input data. Additionally, the user will be asked for: staAbbrev - station abbreviation, will be used in naming output files and for structuring batch jobs constitAbbrev - constitute abbreviation

Usage

getNWISInfo(siteNumber, parameterCd, interactive = TRUE)

Arguments

siteNumber

string USGS site number. This is usually an 8 digit number

parameterCd

string USGS parameter code. This is usually an 5 digit number.

interactive

logical Option for interactive mode. If true, there is user interaction for error handling and data checks.

Value

INFO dataframe with at least param.nm, param.units, parameShortName, paramNumber

Examples

Run this code
# NOT RUN {
# These examples require an internet connection to run
# Automatically gets information about site 05114000 and temperature, no interaction with user
INFO <- getNWISInfo('05114000','00010')
# }

Run the code above in your browser using DataLab