powered by
Imports data from USGS site file site. This function gets data from here: http://waterservices.usgs.gov/
getNWISSiteInfo(siteNumbers)readNWISsite(siteNumbers)
readNWISsite(siteNumbers)
string USGS site number. This is usually an 8 digit number
retval dataframe with all information found in the expanded site file
# NOT RUN { # These examples require an internet connection to run siteINFO <- readNWISsite('05114000') siteINFOMulti <- readNWISsite(c('05114000','09423350')) # }
Run the code above in your browser using DataLab