Learn R Programming

dataRetrieval (version 2.0.0)

getNWISdvData: Raw Data Import for USGS NWIS Data

Description

Imports data from NWIS web service. This function gets the data from here: http://waterservices.usgs.gov/ A list of parameter codes can be found here: http://help.waterdata.usgs.gov/codes-and-parameters/parameters A list of statistic codes can be found here: http://help.waterdata.usgs.gov/code/stat_code_query?fmt=html

Usage

getNWISdvData(siteNumber, parameterCd, startDate = "", endDate = "",
  statCd = "00003")

readNWISdv(siteNumber, parameterCd, startDate = "", endDate = "", statCd = "00003")

Arguments

siteNumber

string USGS site number. This is usually an 8 digit number. Multiple sites can be requested with a string vector.

parameterCd

string or vector of USGS parameter code. This is usually an 5 digit number..

startDate

string starting date for data retrieval in the form YYYY-MM-DD.

endDate

string ending date for data retrieval in the form YYYY-MM-DD.

statCd

string USGS statistic code. This is usually 5 digits. Daily mean (00003) is the default.

Value

data dataframe with agency, site, dateTime, value, and code columns

Examples

Run this code
# NOT RUN {
siteNumber <- '04085427'
startDate <- '2012-01-01'
endDate <- '2012-06-30'
pCode <- '00060'
# }
# NOT RUN {
rawDailyQ <- readNWISdv(siteNumber,pCode, startDate, endDate)
rawDailyQAndTempMeanMax <- readNWISdv(siteNumber,c('00010','00060'),
       startDate, endDate, statCd=c('00001','00003'))
rawDailyQAndTempMeanMax <- renameNWISColumns(rawDailyQAndTempMeanMax)
rawDailyMultiSites<- readNWISdv(c("01491000","01645000"),c('00010','00060'),
       startDate, endDate, statCd=c('00001','00003'))
# Site with no data:
x <- readNWISdv("10258500","00060", "2014-09-08", "2014-09-14")
names(attributes(x))
attr(x, "siteInfo")
attr(x, "variableInfo")
# }

Run the code above in your browser using DataLab