Learn R Programming

dataRetrieval (version 2.0.0)

getNWISunitData: Raw Data Import for Instantaneous USGS NWIS Data

Description

Imports data from NWIS web service. This function gets the data from here: http://waterservices.usgs.gov/ A list of parameter codes can be found here: http://nwis.waterdata.usgs.gov/nwis/pmcodes/ A list of statistic codes can be found here: http://nwis.waterdata.usgs.gov/nwis/help/?read_file=stat&format=table

Usage

getNWISunitData(siteNumbers, parameterCd, startDate = "", endDate = "",
  tz = "")

readNWISuv(siteNumbers, parameterCd, startDate = "", endDate = "", tz = "")

Arguments

siteNumbers

string USGS site number (or multiple sites). This is usually an 8 digit number

parameterCd

string USGS parameter code. This is usually an 5 digit number.

startDate

string starting date for data retrieval in the form YYYY-MM-DD.

endDate

string ending date for data retrieval in the form YYYY-MM-DD.

tz

string to set timezone attribute of datetime. Default is an empty quote, which converts the datetimes to UTC (properly accounting for daylight savings times based on the data's provided tz_cd column). Possible values to provide are "America/New_York","America/Chicago", "America/Denver","America/Los_Angeles", "America/Anchorage","America/Honolulu","America/Jamaica","America/Managua","America/Phoenix", and "America/Metlakatla"

Value

data dataframe with agency, site, dateTime, time zone, value, and code columns

Examples

Run this code
# NOT RUN {
siteNumber <- '05114000'
parameterCd <- '00060'
startDate <- "2014-10-10"
endDate <- "2014-10-10"
# These examples require an internet connection to run
rawData <- readNWISuv(siteNumber,parameterCd,startDate,endDate)

timeZoneChange <- readNWISuv(c('04024430','04024000'),parameterCd,
         "2013-11-03","2013-11-03")
firstSite <- timeZoneChange[timeZoneChange$site_no == '04024430',]
# }

Run the code above in your browser using DataLab