Learn R Programming

dataRetrieval (version 1.4.0)

getUserSample: Import user sample data for EGRET analysis

Description

Imports data from a user-supplied file, and converts it to a Sample data frame (including summing multiple constituents), appropriate for WRTDS calculations.

Usage

getUserSample(filePath, fileName, hasHeader = TRUE, separator = ",",
  interactive = TRUE)

Arguments

filePath

string specifying the path to the file

fileName

string name of file to open

hasHeader

logical true if the first row of data is the column headers

separator

string character that separates data cells

interactive

logical Option for interactive mode. If true, there is user interaction for error handling and data checks.

Value

Sample dataframe

See Also

compressData, populateSampleColumns

Examples

Run this code
# NOT RUN {
filePath <- system.file("extdata", package="dataRetrieval")
filePath <- paste(filePath,"/",sep="")
fileName <- 'ChoptankRiverNitrate.csv'
Sample <- getUserSample(filePath,fileName, separator=";",interactive=FALSE)
# }

Run the code above in your browser using DataLab