Learn R Programming

dataRetrieval (version 2.0.0)

getWQPData: General Data Import from Water Quality Portal

Description

Imports data from Water Quality Portal web service. This function gets the data from here: http://www.waterqualitydata.us. because it allows for other agencies rather than the USGS.

Usage

getWQPData(...)

readWQPdata(...)

Arguments

Value

retval dataframe with first column dateTime, and at least one qualifier and value columns (subsequent qualifier/value columns could follow depending on requested parameter codes)

Examples

Run this code
# NOT RUN {
nameToUse <- "pH"
pHData <- readWQPdata(siteid="USGS-04024315",characteristicName=nameToUse)
# }

Run the code above in your browser using DataLab