Learn R Programming

dataRetrieval (version 1.4.0)

getWQPSample: Import Sample Data for WRTDS

Description

Imports data from the Water Quality Portal, so it could be STORET, NWIS, or . This function gets the data from: http://www.waterqualitydata.us For raw data, use getWQPData. This function will retrieve the raw data, and compress it (summing constituents). See chapter 7 of the EGRET user guide for more details, then converts it to the Sample dataframe structure.

Usage

getWQPSample(siteNumber, characteristicName, startDate, endDate,
  interactive = TRUE)

Arguments

siteNumber

string site number. If USGS, it should be in the form :'USGS-XXXXXXXXX...'

characteristicName

string

startDate

string starting date for data retrieval in the form YYYY-MM-DD.

endDate

string ending date for data retrieval in the form YYYY-MM-DD.

interactive

logical Option for interactive mode. If true, there is user interaction for error handling and data checks.

Value

Sample dataframe

See Also

getWQPData, getWQPSites, getWQPqwData, getNWISqwData, and readWQPData, compressData, populateSampleColumns

Examples

Run this code
# NOT RUN {
# These examples require an internet connection to run
# }
# NOT RUN {
Sample_01075 <- getWQPSample('USGS-01594440','Chloride', '', '')
Sample_All <- getWQPSample('WIDNR_WQX-10032762','Specific conductance', '', '')
# }

Run the code above in your browser using DataLab