Learn R Programming

dataRetrieval (version 1.4.0)

getWQPSites: Site Data Import from Water Quality Portal

Description

Returns a list of sites from the Water Quality Portal web service. This function gets the data from: http://www.waterqualitydata.us. Arguments to the function should be based on www.waterqualitydata.us/webservices_documentation.jsp

Usage

getWQPSites(...)

Arguments

Value

retval dataframe with first column dateTime, and at least one qualifier and value columns (subsequent qualifier/value columns could follow depending on requested parameter codes)

Examples

Run this code
# NOT RUN {
site1 <- getWQPSites(siteid="USGS-01594440")
type <- "Stream"
sites <- getWQPSites(statecode="US:55",countycode="US:55:025",siteType=type)
# }

Run the code above in your browser using DataLab