Learn R Programming

dataRetrieval (version 1.4.0)

mergeReport: Merge Sample and Daily Data for WRTDS

Description

Merges the flow data from the daily record into the sample record.

Usage

mergeReport(Daily, Sample, interactive = TRUE)

Arguments

Daily

dataframe containing the daily data, default is Daily

Sample

dataframe containing the sample data, default is Sample

interactive

logical Option for interactive mode. If true, there is user interaction for error handling and data checks.

Value

newSample dataframe with merged flow information

See Also

getNWISDaily, getNWISSample

Examples

Run this code
# NOT RUN {
# These examples require an internet connection to run
Daily <- getNWISDaily('01594440','00060', '1985-01-01', '1985-03-31')
Sample <- getNWISSample('01594440','01075', '1985-01-01', '1985-03-31')
Sample <- mergeReport(Daily, Sample)
# }

Run the code above in your browser using DataLab