header_tag.html

Skip to contents

This function no longer works because the underlying service has been removed. Similar functionality can be found with check_waterdata_sample_params.

Usage

pcode_to_name(parameterCd = "all")

Arguments

parameterCd

character that contains the code for a character vector of 5-digit parameter codes.

Examples

pcodes <- c("00070", "00075", "00430", "52642")
# \donttest{
all_new <- read_waterdata_parameter_codes(parameter_code = pcodes)
#> Requesting:
#> https://api.waterdata.usgs.gov/ogcapi/v1/collections/parameter-codes/items?f=json&lang=en-US&limit=50000&id=00070,00075,00430,52642
#> Remaining requests this hour:2782 
ref_list <- check_waterdata_sample_params("reference-list")
#> GET: https://api.waterdata.usgs.gov/samples-data/reference-list?mimeType=application%2Fjson
ref_list_sm <- ref_list[ref_list$parm_cd %in% pcodes, ]

# }