Learn R Programming

dataRetrieval (version 1.4.0)

populateDaily: Populate Daily data frame

Description

Using raw data that has at least dateTime, value, code, populates the rest of the basic Daily data frame used in WRTDS

Usage

populateDaily(rawData, qConvert, interactive = TRUE)

Arguments

rawData

dataframe contains at least dateTime, value, code columns

qConvert

string conversion to cubic meters per second

interactive

logical Option for interactive mode. If true, there is user interaction for error handling and data checks.

Value

dataframe Daily

Examples

Run this code
# NOT RUN {
dateTime <- c('1985-01-01', '1985-01-02', '1985-01-03')
value <- c(1,2,3)
code <- c("","","")
dataInput <- data.frame(dateTime, value, code, stringsAsFactors=FALSE)
Daily <- populateDaily(dataInput, 2)
# }

Run the code above in your browser using DataLab