powered by
Populates INFO data frame with additional user-supplied information. Also removes fields not related to WRTDS study.
populateSiteINFO(INFO, siteNumber, interactive = TRUE)
dataframe with value and code columns
string USGS site number
logical Option for interactive mode. If true, there is user interaction for error handling and data checks.
INFO dataframe
# NOT RUN { #This example requires an internet connection to run INFO <- getNWISSiteInfo('01594440') siteNumber <- "01594440" siteINFO <- populateSiteINFO(INFO, siteNumber) # }
Run the code above in your browser using DataLab