processQWData: Processing of USGS NWIS Water Quality Data
Description
Processes water quality portal data. This function looks at detection limit and detection
conditions to determine if a value is left censored or not. Censored values are given the qualifier
"<". The dataframe is also converted from a long to wide format.
Usage
processQWData(data, pCode = TRUE)
Arguments
data
dataframe from Water Quality Portal
pCode
logical if TRUE, assume data came from a pCode search, if FALSE, characteristic name.
Value
data dataframe with first column dateTime, and at least one qualifier and value columns
(subsequent qualifier/value columns could follow depending on the number of parameter codes)
# NOT RUN {# These examples require an internet connection to run# }# NOT RUN {rawSample <- getWQPqwData('USGS-01594440','', '', '')
rawSampleSelect <- processQWData(rawSample)
# }