Learn R Programming

dataRetrieval (version 2.0.1)

readNWISpCode: USGS Parameter Data Retrieval

Description

Imports data from NWIS about meaured parameter based on user-supplied parameter code. This function gets the data from here: http://nwis.waterdata.usgs.gov/nwis/pmcodes

Usage

readNWISpCode(parameterCd)

Arguments

parameterCd
character of USGS parameter codes (or multiple parameter codes). This is usually an 5 digit number.

Value

  • parameterData data frame with all information from the USGS about the particular parameter. lll{ Name Type Description parameter_cd character 5-digit USGS parameter code parameter_group_nm character USGS parameter group name parameter_nm character USGS parameter name casrn character Chemical Abstracts Service (CAS) Registry Number srsname character Substance Registry Services Name parameter_units character Parameter units }

Examples

Run this code
paramINFO <- readNWISpCode(c('01075','00060','00931'))

Run the code above in your browser using DataLab