| readNWISuse | R Documentation |
Retrieves water use data from USGS Water Use Data for the Nation.
readNWISuse(
stateCd,
countyCd,
years = "ALL",
categories = "ALL",
convertType = TRUE,
transform = FALSE
)
stateCd |
could be character (full name, abbreviation, id), or numeric (id). Only one is accepted per query. |
countyCd |
could be character (name, with or without "County", or "ALL"),
numeric (id), or |
years |
integer Years for data retrieval. Must be years ending in 0 or 5. Default is all available years. |
categories |
character categories of water use. Defaults to "ALL". Specific categories must be supplied as two- letter abbreviations as seen in the URL when using the NWIS water use web interface. Note that there are different codes for national and state level data. |
convertType |
logical defaults to |
transform |
logical only intended for use with national data. Defaults to
|
A data frame with at least the year of record, and all available statistics for the given geographic parameters. County and state fields will be included as appropriate.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.