View source: R/read_waterdata_field_measurements.R
| read_waterdata_field_measurements | R Documentation |
Field measurements are physically measured values collected during a visit to the monitoring location. Field measurements consist of measurements of gage height and discharge, and readings of groundwater levels, and are primarily used as calibration readings for the automated sensors collecting continuous data. They are collected at a low frequency, and delivery of the data in WDFN may be delayed due to data processing time.
read_waterdata_field_measurements(
monitoring_location_id = NA_character_,
parameter_code = NA_character_,
observing_procedure_code = NA_character_,
properties = NA_character_,
field_visit_id = NA_character_,
approval_status = NA_character_,
unit_of_measure = NA_character_,
qualifier = NA_character_,
value = NA,
last_modified = NA_character_,
observing_procedure = NA_character_,
vertical_datum = NA_character_,
measuring_agency = NA_character_,
control_condition = NA_character_,
measurement_rated = NA_character_,
skipGeometry = NA,
time = NA_character_,
bbox = NA,
limit = NA,
convertType = TRUE,
no_paging = FALSE
)
monitoring_location_id |
A unique identifier representing a single monitoring location. This corresponds to the Multiple monitoring_location_ids can be requested as a character vector. |
parameter_code |
Parameter codes are 5-digit codes used to identify the constituent measured and the units of measure. A complete list of parameter codes and associated groupings can be found at https://api.waterdata.usgs.gov/ogcapi/v0/collections/parameter-codes/items. Multiple parameter_codes can be requested as a character vector. |
observing_procedure_code |
A short code corresponding to the observing procedure for the field measurement. |
properties |
A vector of requested columns to be returned from the query.
Available options are:
geometry, field_measurement_id, field_visit_id, parameter_code, monitoring_location_id, observing_procedure_code, observing_procedure, value, unit_of_measure, time, qualifier, vertical_datum, approval_status, measuring_agency, last_modified, control_condition, measurement_rated.
The default ( |
field_visit_id |
A universally unique identifier (UUID) for the field visit. Multiple measurements may be made during a single field visit. |
approval_status |
Some of the data that you have obtained from this U.S. Geological Survey database may not have received Director's approval. Any such data values are qualified as provisional and are subject to revision. Provisional data are released on the condition that neither the USGS nor the United States Government may be held liable for any damages resulting from its use. This field reflects the approval status of each record, and is either "Approved", meaining processing review has been completed and the data is approved for publication, or "Provisional" and subject to revision. For more information about provisional data, go to https://waterdata.usgs.gov/provisional-data-statement/. |
unit_of_measure |
A human-readable description of the units of measurement associated with an observation. |
qualifier |
This field indicates any qualifiers associated with an observation, for instance if a sensor may have been impacted by ice or if values were estimated. |
value |
The value of the observation. Values are transmitted as strings in the JSON response format in order to preserve precision. |
last_modified |
The last time a record was refreshed in our database. This may happen due to regular operational processes and does not necessarily indicate anything about the measurement has changed. You can query this field using date-times or intervals, adhering to RFC 3339, or using ISO 8601 duration objects. Intervals may be bounded or half-bounded (double-dots at start or end). Examples:
Only features that have a See also Details below for more information. |
observing_procedure |
Water measurement or water-quality observing procedure descriptions. |
vertical_datum |
The datum used to determine altitude and vertical position at the monitoring location. A list of codes is available at https://api.waterdata.usgs.gov/ogcapi/v0/collections/altitude-datums/items. |
measuring_agency |
The agency performing the measurement. |
control_condition |
What and where the control of flow is for the gage pool. |
measurement_rated |
Rated measurement based on the hydrologic/hydraulic conditions in which the measurement was made (excellent (2 percent), good (5 percent), fair (8 percent), or poor (more than 8 percent). percent) |
skipGeometry |
This option can be used to skip response geometries for each feature. The returning object will be a data frame with no spatial information. |
time |
The date an observation represents. You can query this field using date-times or intervals, adhering to RFC 3339, or using ISO 8601 duration objects. Intervals may be bounded or half-bounded (double-dots at start or end). Examples:
Only features that have a See also Details below for more information. |
bbox |
Only features that have a geometry that intersects the bounding box are selected.The bounding box is provided as four or six numbers, depending on whether the coordinate reference system includes a vertical axis (height or depth). Coordinates are assumed to be in crs 4326. The expected format is a numeric vector structured: c(xmin,ymin,xmax,ymax). Another way to think of it is c(Western-most longitude, Southern-most latitude, Eastern-most longitude, Northern-most longitude). |
limit |
The optional limit parameter is used to control the subset of the
selected features that should be returned in each page. The maximum allowable
limit is 50000. It may be beneficial to set this number lower if your internet
connection is spotty. The default ( |
convertType |
logical, defaults to |
no_paging |
logical, defaults to |
You can also use a vector of length 2 for any time queries (such as time
or last_modified). The first value is the starting date (or datetime),
the second value is the ending date(or datetime).
NA's within the vector indicate a half-bound date.
For example, time = c("2024-01-01", NA) will return all data starting
at 2024-01-01.
time = c(NA, "2024-01-01") will return all data from the beginning of
the timeseries until 2024-01-01.
By default, time is assumed UTC, although time zone attributes
will be accommodated. As an example, setting time = as.POSIXct(c("2021-01-01 12:00:00",
"2021-01-01 14:00"), tz = "America/New_York") will request data that between
noon and 2pm eastern time on 2021-01-01.
All time values RETURNED from the service are UTC with the exception of
daily data, which returns time values in local dates.
site <- "USGS-02238500"
field_data_sf <- read_waterdata_field_measurements(monitoring_location_id = site)
groundwater <- read_waterdata_field_measurements(monitoring_location_id = "USGS-375907091432201")
field_data <- read_waterdata_field_measurements(monitoring_location_id = "USGS-02238500",
parameter_code = "00060",
time = as.POSIXct(c("2024-02-26 15:00:00",
"2025-08-27 12:00:00"),
tz = "America/Chicago"),
skipGeometry = TRUE)
gwl_data_period <- read_waterdata_field_measurements(
monitoring_location_id = "USGS-375907091432201",
parameter_code = "72019",
time = "P20Y")
multi_site <- read_waterdata_field_measurements(
monitoring_location_id = c("USGS-451605097071701",
"USGS-263819081585801"),
parameter_code = c("62611", "72019"))
old_df <- read_waterdata_field_measurements(monitoring_location_id = "USGS-425957088141001",
time = c("1980-01-01", NA))
surface_water <- read_waterdata_field_measurements(
monitoring_location_id = c("USGS-07069000",
"USGS-07064000",
"USGS-07068000"),
time = "2024-07-01T00:00:00Z/..",
parameter_code = "00060")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.