Learn R Programming

dataRetrieval (version 1.4.0)

removeDuplicates: Remove Duplicates

Description

Removes observations from the data frame Sample when the observation has the identical date and value as another observation

Usage

removeDuplicates(Sample)

Arguments

Sample

dataframe with at least DecYear and ConcHigh, default name is Sample

Value

Sample1 dataframe

Examples

Run this code
# NOT RUN {
DecYear <- c('1985.01', '1985.01', '1985.02', '1985.02', '1985.03')
ConcHigh <- c(1,2,3,3,5)
dataInput <- data.frame(DecYear, ConcHigh, stringsAsFactors=FALSE)
removeDuplicates(dataInput)
# }

Run the code above in your browser using DataLab