| check_arguments_api | R Documentation |
Additional functions to check types and create parameter descriptions.
check_arguments_api(bbox, skipGeometry)
bbox |
Only features that have a geometry that intersects the bounding box are selected.The bounding box is provided as four or six numbers, depending on whether the coordinate reference system includes a vertical axis (height or depth). Coordinates are assumed to be in crs 4326. The expected format is a numeric vector structured: c(xmin,ymin,xmax,ymax). Another way to think of it is c(Western-most longitude, Southern-most latitude, Eastern-most longitude, Northern-most longitude). |
skipGeometry |
This parameter can be used to skip response geometries for
each feature. The returning object will be a data frame with no spatial
information. The default |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.