| check_arguments_non_api | R Documentation |
Function to check types and create parameter descriptions.
check_arguments_non_api(
convertType,
no_paging,
limit,
attach_request,
chunk_size,
...
)
convertType |
logical, defaults to TRUE.
If |
no_paging |
logical, defaults to FALSE.
If |
limit |
numeric, The optional limit parameter is used to control the subset of the
selected features that should be returned in each page. The maximum allowable
limit is 50,000. It may be beneficial to set this number lower if your internet
connection is spotty. The default ( |
attach_request |
logical, defaults to TRUE.
If set to |
chunk_size |
Number of monitoring_location_ids to chunk requests into.
The default for functions that don't generally return long-term data records
is 250, while
the default for time series functions is
10.
Setting to |
... |
Not used. Included to help differentiate official Water Data API arguments from more seldom used, optional dataRetrieval-specific arguments. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.