| dataRetrieval | R Documentation |
| Package: | dataRetrieval |
| Type: | Package |
| License: | Unlimited for this package, dependencies have more restrictive licensing. |
| Copyright: | This software is in the public domain because it contains materials that originally came from the United States Geological Survey, an agency of the United States Department of Interior. |
| LazyLoad: | yes |
Retrieval functions for USGS and EPA hydrologic and water quality data.
Please see https://doi-usgs.github.io/dataRetrieval/ for more information.
Laura De Cicco ldecicco@usgs.gov
Useful links:
Report bugs at https://github.com/DOI-USGS/dataRetrieval/issues
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.