powered by
Checks that the parameter code is 5 digits. If it is less, it will pad the string with zeros. If more, ask the user to re-enter.
formatCheckParameterCd(parameterCd, interactive = TRUE)
string to check
logical Option for interactive mode. If true, there is user interaction for error handling and data checks.
parameterCd string
# NOT RUN { pCode <- '01234' formatCheckParameterCd(pCode) # }
Run the code above in your browser using DataLab