powered by
Reads groundwater level measurements from NWISweb. Mixed date/times come back from the service depending on the year that the data was collected.
readNWISgwl(siteNumbers, startDate = "", endDate = "")
string USGS site number (or multiple sites). This is usually an 8 digit number
string starting date for data retrieval in the form YYYY-MM-DD.
string ending date for data retrieval in the form YYYY-MM-DD.
# NOT RUN { siteNumber <- "434400121275801" data <- readNWISgwl(siteNumber, '','') sites <- c("434400121275801", "375907091432201") data2 <- readNWISgwl(sites, '','') # }
Run the code above in your browser using DataLab