Learn R Programming

dataRetrieval (version 2.0.0)

readNWISmeas: Reads surface-water measurement data from NWISweb.

Description

Reads surface-water measurement data from NWISweb.

Usage

readNWISmeas(siteNumber, startDate = "", endDate = "", tz = "")

Arguments

siteNumber

string USGS site number. This is usually an 8 digit number

startDate

string starting date for data retrieval in the form YYYY-MM-DD.

endDate

string ending date for data retrieval in the form YYYY-MM-DD.

tz

string to set timezone attribute of datetime. Default is an empty quote, which converts the datetimes to UTC (properly accounting for daylight savings times based on the data's provided tz_cd column). Possible values to provide are "America/New_York","America/Chicago", "America/Denver","America/Los_Angeles", "America/Anchorage","America/Honolulu","America/Jamaica","America/Managua","America/Phoenix", and "America/Metlakatla"

Examples

Run this code
# NOT RUN {
siteNumber <- '01594440'
data <- readNWISmeas(siteNumber)
# }

Run the code above in your browser using DataLab