Learn R Programming

dataRetrieval (version 2.0.1)

readNWISpeak: Reads peak flow data from NWISweb.

Description

Reads peak flow from NWISweb. Data is retrieved from http://waterdata.usgs.gov/nwis.

Usage

readNWISpeak(siteNumbers, startDate = "", endDate = "")

Arguments

siteNumbers
character USGS site number(or multiple sites). This is usually an 8 digit number.
startDate
character starting date for data retrieval in the form YYYY-MM-DD. Default is "" which indicates retrieval for the earliest possible record.
endDate
character ending date for data retrieval in the form YYYY-MM-DD. Default is "" which indicates retrieval for the latest possible record.

Value

  • A data frame with the following columns: lll{ Name Type Description agency_cd character The NWIS code for the agency reporting the data site_no character The USGS site number peak_dt Date Date of peak streamflow peak_tm character Time of peak streamflow as character peak_va numeric Annual peak streamflow value in cfs peak_cd character Peak Discharge-Qualification codes (see comment for more information) gage_ht numeric Gage height for the associated peak streamflow in feet gage_ht_cd character Gage height qualification codes year_last_pk character Peak streamflow reported is the highest since this year ag_dt character Date of maximum gage-height for water year (if not concurrent with peak) ag_tm character Time of maximum gage-height for water year (if not concurrent with peak) ag_gage_ht character maximum Gage height for water year in feet (if not concurrent with peak) ag_gage_ht_cd character maximum Gage height code } There are also several useful attributes attached to the data frame: lll{ Name Type Description url character The url used to generate the data queryTime POSIXct The time the data was returned comment character Header comments from the RDB file siteInfo data.frame A data frame containing information on the requested sites }

Examples

Run this code
siteNumbers <- c('01594440','040851325')
data <- readNWISpeak(siteNumbers)

Run the code above in your browser using DataLab