readNWISpeak(siteNumbers, startDate = "", endDate = "")comment for more information)
gage_ht numeric Gage height for the associated peak streamflow in feet
gage_ht_cd character Gage height qualification codes
year_last_pk character Peak streamflow reported is the highest since this year
ag_dt character Date of maximum gage-height for water year (if not concurrent with peak)
ag_tm character Time of maximum gage-height for water year (if not concurrent with peak)
ag_gage_ht character maximum Gage height for water year in feet (if not concurrent with peak)
ag_gage_ht_cd character maximum Gage height code
}
There are also several useful attributes attached to the data frame:
siteNumbers <- c('01594440','040851325')
data <- readNWISpeak(siteNumbers)Run the code above in your browser using DataLab