readNWISrating: Reads the current rating table for an active USGS streamgage.
Description
Reads current rating table for an active USGS streamgage from NWISweb.
Data is retrieved from http://waterdata.usgs.gov/nwis.
Usage
readNWISrating(siteNumber, type = "base")
Arguments
siteNumber
character USGS site number. This is usually an 8 digit number
type
character can be "base", "corr", or "exsa"
Value
A data frame. If type is "base," then the columns are
INDEP, typically the gage height, in feet; DEP, typically the streamflow,
in cubic feet per second; and STOR, where "*" indicates that the pair are
a fixed point of the rating curve. If type is "exsa," then an
additional column, SHIFT, is included that indicates the current shift in
the rating for that value of INDEP. If type is "corr," then the
columns are INDEP, typically the gage height, in feet; CORR, the correction
for that value; and CORRINDEP, the corrected value for CORR.
If type is "base," then the data frame has an attribute called "RATING"
that describes the rating curve is included.
There are also several useful attributes attached to the data frame:
lll{
Name Type Description
url character The url used to generate the data
queryTime POSIXct The time the data was returned
comment character Header comments from the RDB file
siteInfo data.frame A data frame containing information on the requested sites
RATING character Rating information
}