Learn R Programming

dataRetrieval (version 2.0.0)

readNWISrating: Reads the current rating table for an active USGS streamgage.

Description

Reads the current rating table for an active USGS streamgage.

Usage

readNWISrating(siteNumber, type = "base")

Arguments

siteNumber

string USGS site number. This is usually an 8 digit number

type

string can be "base", "corr", or "exsa"

Examples

Run this code
# NOT RUN {
siteNumber <- '01594440'
data <- readNWISrating(siteNumber, "base")
attr(data, "RATING")
# }

Run the code above in your browser using DataLab