View source: R/read_waterdata.R
| read_waterdata | R Documentation |
Function that allows complex CQL queries. See https://api.waterdata.usgs.gov/docs/ogcapi/complex-queries/ for more information.
read_waterdata(
service,
CQL,
...,
convertType = getOption("dataRetrieval.convertType"),
limit = getOption("dataRetrieval.limit"),
attach_request = getOption("dataRetrieval.attach_request")
)
service |
character, can be any existing collection. |
CQL |
A string in a Common Query Language format. |
... |
Additional arguments to send to the request. |
convertType |
logical, defaults to |
limit |
numeric, The optional limit parameter is used to control the subset of the
selected features that should be returned in each page. The maximum allowable
limit is 50,000. It may be beneficial to set this number lower if your internet
connection is spotty. The default ( |
attach_request |
logical, defaults to TRUE.
If set to |
cql <- '{
"op": "and",
"args": [
{
"op": "in",
"args": [
{ "property": "parameter_code" },
[ "00060", "00065" ]
]
},
{
"op": "in",
"args": [
{ "property": "monitoring_location_id" },
[ "USGS-07367300", "USGS-03277200" ]
]
}
]
}'
dv_data <- read_waterdata(service = "daily",
CQL = cql,
time = c("2023-01-01", "2024-01-01"))
# A wildcard in CQL2 is %
# Here's how to get HUCs that fall within 02070010
cql_huc_wildcard <- '{
"op": "like",
"args": [
{ "property": "hydrologic_unit_code" },
"02070010%"
]
}'
what_huc_sites <- read_waterdata(service = "monitoring-locations",
CQL = cql_huc_wildcard)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.