Learn R Programming

dataRetrieval (version 2.0.1)

whatNWISsites: Site Data Import from NWIS

Description

Returns a list of sites from the NWIS web service. This function gets the data from: http://waterservices.usgs.gov/rest/Site-Test-Tool.html. Arguments to the function should be based on http://waterservices.usgs.gov/rest/Site-Service.html#Service Mapper format is used

Usage

whatNWISsites(...)

Arguments

...
see http://waterservices.usgs.gov/rest/Site-Service.html#Service for a complete list of options

Value

  • A data frame with at least the following columns: lll{ Name Type Description agency_cd character The NWIS code for the agency reporting the data site_no character The USGS site number station_nm character Station name site_tp_cd character Site type code dec_lat_va numeric Decimal latitude dec_long_va numeric Decimal longitude queryTime POSIXct Query time } There are also several useful attributes attached to the data frame: lll{ Name Type Description url character The url used to generate the data queryTime POSIXct The time the data was returned }

Examples

Run this code
siteListPhos <- whatNWISsites(stateCd="OH",parameterCd="00665")

Run the code above in your browser using DataLab